from typing import Tuple, List


__all__ = ["Point2D", "Segment"]


Point2D = Tuple[float, float]
Segment = List[List[Point2D]]
